@@ -56,7 +56,7 @@ accuracy.MC <- function(dir=NULL){
     assign.rate.each[i,] <- popCorrectRate_vec
   }
   #concatenate all data
-  assign_rate_df <- cbind(train.inds, train.loci, iters, assign.rate.all, assign.rate.each)
+  assign_rate_df <- cbind(train.inds, train.loci, iters, assign.rate.all, assign.rate.each, stringsAsFactors=T)
   names(assign_rate_df)[5:ncol(assign_rate_df)] <- paste0("assign.rate.",pops)
   #output result
   write.table(assign_rate_df, file=paste0(dir,"Rate_of_",nrow(assign_rate_df),"_tests_",noPops,"_pops.txt"), quote=F, row.names=F )
