@@ -5,7 +5,7 @@ test_that("Calculate assignment accuracy for Monte-Carlo results",{
   expect_output(str(AccuMC),"data.frame")
   expect_true(file.exists("ResMCtest/Rate_of_3_tests_3_pops.txt"))
   plot <- accuracy.plot(AccuMC)
-  expect_output(str(plot), "List of 9")
+  expect_type(plot, "list")
 })
 
 unlink("ResMCtest/Rate_of_3_tests_3_pops.txt")
@@ -15,7 +15,7 @@ test_that("Calculate assignment accuracy for K-fold results",{
   expect_output(str(AccuKF),"data.frame")
   expect_true(file.exists("ResKFtest/Rate_of_3_tests_3_pops.txt"))
   plot <- accuracy.plot(AccuKF)
-  expect_output(str(plot), "List of 9")
+  expect_type(plot, "list")
 })
 
 unlink("ResKFtest/Rate_of_3_tests_3_pops.txt")
