@@ -2,5 +2,5 @@ context("Test membership.prob.plot")
 
 test_that("Plot membership probability",{
   plot <- membership.plot(dir="ResKFtest/", style=1, non.genetic=T)
-  expect_output(str(plot), "List of 10")
+  expect_type(plot, "list")
 })
\ No newline at end of file
